@@ -15,7 +15,7 @@
 # You should have received a copy of the GNU General Public License
 # along with Bio::MAGETAB.  If not, see <http://www.gnu.org/licenses/>.
 #
-# $Id: ADF.pm 316 2009-05-05 13:28:56Z tfrayner $
+# $Id: ADF.pm 320 2009-05-05 16:53:27Z tfrayner $
 
 package Bio::MAGETAB::Util::Reader::ADF;
 
@@ -796,7 +796,7 @@ class which handles extended parsing options more transparently.
 
 =head1 ATTRIBUTES
 
-See L<Bio::MAGETAB::Util::Reader::TagValueFile> for superclass attributes.
+See the L<TagValueFile|Bio::MAGETAB::Util::Reader::TagValueFile> class for superclass attributes.
 
 =over 2
 
@@ -821,9 +821,9 @@ Bio::MAGETAB::ArrayDesign object updated with the ADF contents.
 
 =head1 SEE ALSO
 
-L<Bio::MAGETAB::Util::Reader::TagValueFile>,
-L<Bio::MAGETAB::Util::Reader::Tabfile>,
-L<Bio::MAGETAB::Util::Reader>,
+L<Bio::MAGETAB::Util::Reader::TagValueFile>
+L<Bio::MAGETAB::Util::Reader::Tabfile>
+L<Bio::MAGETAB::Util::Reader>
 L<Bio::MAGETAB::ArrayDesign>
 
 =head1 AUTHOR
