@@ -15,7 +15,7 @@
 # You should have received a copy of the GNU General Public License
 # along with Bio::MAGETAB.  If not, see <http://www.gnu.org/licenses/>.
 #
-# $Id: SDRF.pm 317 2009-05-05 15:23:50Z tfrayner $
+# $Id: SDRF.pm 320 2009-05-05 16:53:27Z tfrayner $
 
 package Bio::MAGETAB::Util::Reader::SDRF;
 
@@ -1228,7 +1228,7 @@ class which handles extended parsing options more transparently.
 
 =head1 ATTRIBUTES
 
-See L<Bio::MAGETAB::Util::Reader::TabFile> for superclass attributes.
+See the L<TabFile|Bio::MAGETAB::Util::Reader::TabFile> class for superclass attributes.
 
 =over 2
 
@@ -1253,8 +1253,8 @@ Bio::MAGETAB::SDRF object updated with the SDRF contents.
 
 =head1 SEE ALSO
 
-L<Bio::MAGETAB::Util::Reader::Tabfile>,
-L<Bio::MAGETAB::Util::Reader>,
+L<Bio::MAGETAB::Util::Reader::Tabfile>
+L<Bio::MAGETAB::Util::Reader>
 L<Bio::MAGETAB::SDRF>
 
 =head1 AUTHOR
