@@ -15,7 +15,7 @@
 # You should have received a copy of the GNU General Public License
 # along with Bio::MAGETAB.  If not, see <http://www.gnu.org/licenses/>.
 #
-# $Id: IDF.pm 320 2009-05-05 16:53:27Z tfrayner $
+# $Id: IDF.pm 327 2010-02-02 18:02:46Z tfrayner $
 
 package Bio::MAGETAB::Util::Writer::IDF;
 
@@ -236,6 +236,9 @@ sub write {
     } keys %multi;
     $self->set_num_columns( 1 + max @objcounts );
 
+    # Introduce a Version tag (new in v1.1).
+    $self->_write_line( 'MAGE-TAB Version', '1.1' );
+
     # Single elements are straightforward.
     while ( my ( $field, $value ) = each %single ) {
         my $getter = "get_$value";
@@ -281,7 +284,7 @@ objects.
  use Bio::MAGETAB::Util::Writer::IDF;
  my $writer = Bio::MAGETAB::Util::Writer::IDF->new({
     magetab_object => $investigation,
-    filename       => $idf_fh,
+    filehandle     => $idf_fh,
  });
  
  $writer->write();
