@@ -15,7 +15,7 @@
 # You should have received a copy of the GNU General Public License
 # along with Bio::MAGETAB.  If not, see <http://www.gnu.org/licenses/>.
 #
-# $Id: SDRF.pm 320 2009-05-05 16:53:27Z tfrayner $
+# $Id: SDRF.pm 325 2009-08-28 14:50:28Z tfrayner $
 
 package Bio::MAGETAB::Util::Writer::SDRF;
 
@@ -805,7 +805,7 @@ objects.
  use Bio::MAGETAB::Util::Writer::SDRF;
  my $writer = Bio::MAGETAB::Util::Writer::SDRF->new({
     magetab_object => $sdrf_object,
-    filename       => $sdrf_fh,
+    filehandle     => $sdrf_fh,
  });
  
  $writer->write();
